@@ -32,9 +32,9 @@ CanvasWidget::CanvasWidget(QWidget *parent) :
     KgDeclarativeView(parent),
     m_provider(new KgThemeProvider)
 {
-    m_provider->discoverThemes("appdata", QLatin1String("themes"));
-    m_provider->setDeclarativeEngine(QLatin1Literal("themeProvider"), engine());
-    QString path = QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1Literal("qml/main.qml"));
+    m_provider->discoverThemes("appdata", QStringLiteral("themes"));
+    m_provider->setDeclarativeEngine(QStringLiteral("themeProvider"), engine());
+    QString path = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("qml/main.qml"));
     setSource(QUrl::fromLocalFile(path));
 
     // forward signals from QML
